@@ -30,7 +30,7 @@ test_that("pop_age doesn't change total population size", {
 
   # Even with interpolation
   expect_warning(
-    ages_it_2015_cat <- pop_age(ages_it_2015, age.limit = c(0, 18, 40, 65)),
+    ages_it_2015_cat <- pop_age(ages_it_2015, age.limit = c(0, 18, 40, 65)), # nolint
     "Linearly estimating"
   )
 
@@ -40,7 +40,7 @@ test_that("pop_age doesn't change total population size", {
   )
 })
 
-test_that("pop_age throws warnings/errors", {
+test_that("pop_age throws warnings or errors", {
   expect_error(pop_age(3), "to be a data.frame")
   expect_warning(wpp_age("Germany", 2011), "Don't have population data")
 })
